AnalyticsProperties class

Constructors

AnalyticsProperties({String? category, String? label, String? action, String? track})
const
AnalyticsProperties.fromJson(dynamic properties)
factory

Properties

action → String?
final
category → String?
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
track → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

key ↔ String
getter/setter pair